import * as typeIs from './typeIs';
import * as testHelpers from './testHelpers';
export { typeIs, testHelpers };
/** Helper type to check if element is a specific React Component  */
export function isComponentType(element, displayName) {
    return (element != null &&
        typeof element === 'object' &&
        'type' in element &&
        element.type.displayName === displayName);
}
/**
 * Utility for making it easier to couple a React Component to a css selector.
 * Useful when writing css selectors that rely on interactivity, i.e. :hover.
 * Example:
 *  const checkBoxWrapper = createDataProp('checkbox-wrapper');
 *  // Used as selector:
 *  css`&:hover ${checkboxWrapper.selector} { }`
 *  // Used on React Component
 *  <div {...checkboxWrapper.prop} />
 * @param {string} name Name of element we want to reference.
 */
export function createDataProp(name) {
    var _a;
    // ts:emit throws an error if this is not typed. Usually this can be inferred.
    var prefix = 'data-leafygreen-ui';
    return {
        prop: (_a = {},
            _a[prefix] = name,
            _a),
        selector: "[" + prefix + "=\"" + name + "\"]",
    };
}
/** Object mapping keyCodes to keys */
export var keyMap = {
    ArrowUp: 38,
    ArrowDown: 40,
    ArrowLeft: 37,
    ArrowRight: 39,
    Enter: 13,
    Escape: 27,
    Space: 32,
    Tab: 9,
};
/**
 * An enum of accepted values for the "aria-current" attribute, used for
 * indicating current/active state across several contexts.
 *
 * The values "false", the empty string, and an ommission of this attribute
 * are all treated identically by user agents and screen readers.
 *
 * W3C Recommendation: https://www.w3.org/TR/wai-aria-1.1/#aria-current
 */
export var AriaCurrentValue = {
    Page: 'page',
    Step: 'step',
    Location: 'location',
    Date: 'date',
    Time: 'time',
    True: 'true',
    Unset: 'false',
};
//# sourceMappingURL=index.js.map